/**
  *  \file client/scr-sim.h
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_SCR_SIM_H
#define PCC_V2_CLIENT_SCR_SIM_H

#include "game/sim-if.h"
#include "ui/window.h"
#include "ui/widgets/button.h"

class GSimState;
class WSimList;
class GSimulatorGameInterface;

class WSimScreen : public UIWindow {
    ObjectHolder h;

    WSimList& ed_list;
    GSimulatorGameInterface& game_if;
    UIButton& btn_extras;

    void init();
 public:
    WSimScreen(GSimulatorGameInterface& game_if);
    ~WSimScreen();

    void editPlanet();
    void loadFile();
    void saveFile();
    void doFleetCostComparison();
    void runSimulation();
    void writeToGame();
    void updateFromGame();
    bool handleEvent(const UIEvent& event, bool second_pass);
    void onContextMenu();
    void onExtraMenu();
    void sortBy(bool compare(const GSimShip& a, const GSimShip& b));

    static GSimState sim_state;
    static GSimOptions sim_opts;
    static bool sim_default_relations;

    static bool isExpGame();

    static void setDefaultRelations(GSimulatorGameInterface& game_if);
};

void initSimulatorState();
void doneSimulatorState();

int doSimulator(GSimulatorGameInterface& game_iface);

extern const struct ModuleInitializer mod_sim[];


#endif
