/**
  *  \file client/tiles/ufosettings.cc
  *  \brief Ufo Settings tile
  *
  *  (c) 2001-2021 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/ufosettings.h"
#include "util/nls.h"
#include "ui/uiglobal.h"
#include "game/ufo.h"
#include "game/univ.h"
#include "game/objsel.h"

WUfoSettingsTile::WUfoSettingsTile(GObjectSelection& selection)
    : WObjectSelectionObserverTile(font_sizes[FONT_NORMAL].scaledBy(30, 2), selection),
      btn_k(0, "K", 'k'),
      btn_x(0, "X", 'x')
{
    init();
}

WUfoSettingsTile::~WUfoSettingsTile()
{ }

void
WUfoSettingsTile::init()
{
    const int h = font_heights[FONT_NORMAL];
    btn_k.setState(UIButton::bf_SmallSize, true);
    btn_k.addCall(this, &WUfoSettingsTile::onKeep);
    btn_x.setState(UIButton::bf_SmallSize, true);
    btn_x.addCall(this, &WUfoSettingsTile::onOtherEnd);
    setLayout(LeftJustified, 0, true);
    addControl(GfxRect(0, 0, h-1, h-1), btn_k);
    addControl(GfxRect(0, h, h-1, h-1), btn_x);
}

void
WUfoSettingsTile::onKeep()
{
    GUfo* u = dynamic_cast<GUfo*>(getCurrentObject());
    if (u) {
        u->setIsStoredInHistory(!u->isStoredInHistory());
        getCurrentUniverse()->doScreenUpdates();
    }
}

void
WUfoSettingsTile::onOtherEnd()
{
    GObjectType& type = *getObjectType();
    GUfo* u = dynamic_cast<GUfo*>(getCurrentObject());
    GUfo* oe;
    if (u != 0 && (oe = u->getOtherEnd()) != 0) {
        /* Oh, well.... */
        int index = 0;
        while ((index = type.findNextIndexNoWrap(index, false)) != 0 && &type.getObjectByIndex(index) != oe)
            ;
        getObjectSelection().setCurrentIndex(index);
    }
}

void
WUfoSettingsTile::drawData(GfxCanvas& can)
{
    GUfo* u = dynamic_cast<GUfo*>(getCurrentObject());
    if (!u)
        return;

    GfxRect pos = getInnerSize(0, 0);
    const int dy = font_heights[FONT_NORMAL];
    const int x0 = font_heights[FONT_NORMAL] + 5;
    const int x1 = font_ems[FONT_NORMAL]*13;
    const int w  = pos.w - x1;
    const int y  = 0;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setSolidBackground();
    ctx.setColor(UIColor::tc_Static);

    // Line 1:
    outText (ctx, x0, y, _("Keep:"));
    outTextF(ctx, x1, y, w, u->isStoredInHistory() ? _("yes") : _("no"));

    // Line 2:
    outText (ctx, x0, y+dy, _("Other end:"));
    if (GUfo* oe = u->getOtherEnd()) {
        outTextF(ctx, x1, y+dy, w, oe->getName(GObject::LongName));
    } else {
        outTextF(ctx, x1, y+dy, w, _("none/not known"));
    }
}
